==> org.apache.sling.pipes-2.0.2-source-release.zip: org.apache.sling.pipes-2.0.2/src/test/java/org/apache/sling/pipes/dummies/DummySearch.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.sling.pipes.dummies;

import java.util.Collections;
import java.util.Iterator;

import javax.jcr.Node;
import javax.jcr.NodeIterator;

import org.apache.sling.api.resource.Resource;
import org.apache.sling.pipes.BasePipe;
import org.apache.sling.pipes.Plumber;

/**
 * dummy search reads its conf node children and returns them.
 */
public class DummySearch extends BasePipe {

    public DummySearch(Plumber plumber, Resource resource) throws Exception {
        super(plumber, resource);
    }

    @Override
    public boolean modifiesContent() {
        return false;
    }

    @Override
    public Iterator<Resource> getOutput() {
        try {
            final NodeIterator iterator = getConfiguration().adaptTo(Node.class).getNodes();
            return new Iterator<Resource>() {

                @Override
                public boolean hasNext() {
                    return iterator.hasNext();
                }

                @Override
                public Resource next() {
                    try {
                        return resolver.getResource(iterator.nextNode().getPath());
                    } catch (Exception e) {

                    }
                    return null;
                }

                @Override
                public void remove() {

                }
            };
        } catch (Exception e){

        }
        return Collections.<Resource>emptyList().iterator();
    }
}

==> org.apache.sling.pipes-3.0.2-source-release.zip: org.apache.sling.pipes-3.0.2/src/test/java/org/apache/sling/pipes/dummies/DummySearch.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.sling.pipes.dummies;

import java.util.Collections;
import java.util.Iterator;

import javax.jcr.Node;
import javax.jcr.NodeIterator;

import org.apache.sling.api.resource.Resource;
import org.apache.sling.pipes.BasePipe;
import org.apache.sling.pipes.PipeBindings;
import org.apache.sling.pipes.Plumber;

/**
 * dummy search reads its conf node subpipes and returns them.
 */
public class DummySearch extends BasePipe {

    public DummySearch(Plumber plumber, Resource resource, PipeBindings upperBindings) throws Exception {
        super(plumber, resource, upperBindings);
    }

    @Override
    public boolean modifiesContent() {
        return false;
    }

    @Override
    public Iterator<Resource> getOutput() {
        try {
            final NodeIterator iterator = getConfiguration().adaptTo(Node.class).getNodes();
            return new Iterator<Resource>() {

                @Override
                public boolean hasNext() {
                    return iterator.hasNext();
                }

                @Override
                public Resource next() {
                    try {
                        return resolver.getResource(iterator.nextNode().getPath());
                    } catch (Exception e) {

                    }
                    return null;
                }

                @Override
                public void remove() {

                }
            };
        } catch (Exception e){

        }
        return Collections.<Resource>emptyList().iterator();
    }
}
